@@ -158,7 +158,7 @@ dodgr_centrality <- function (graph,
     if (contract && !methods::is (graph, "dodgr_contracted")) {
         graph_full <- graph
         graph <- dodgr_contract_graph (graph)
-        hashc <- get_hash (graph, hash = FALSE)
+        hashc <- get_hash (graph, contracted = TRUE)
         fname_c <- fs::path (
             fs::path_temp (),
             paste0 ("dodgr_edge_map_", hashc, ".Rds")
@@ -386,7 +386,7 @@ estimate_centrality_time <- function (graph,
     }
     if (contract && !methods::is (graph, "dodgr_contracted")) {
         graph <- dodgr_contract_graph (graph)
-        hashc <- get_hash (graph, hash = FALSE)
+        hashc <- get_hash (graph, contracted = TRUE)
         fname_c <- fs::path (
             fs::path_temp (),
             paste0 ("dodgr_edge_map_", hashc, ".Rds")
