@@ -29,6 +29,7 @@ dodgr_to_sf <- function (graph) {
     }
 
     graph <- tbl_to_df (graph)
+    attr (graph, "hash") <- get_hash (graph, contracted = FALSE, force = TRUE)
 
     requireNamespace ("sf")
     res <- dodgr_to_sfc (graph)
@@ -87,9 +88,7 @@ dodgr_to_sfc <- function (graph) {
     names (graph) [gr_cols$xto] <- "to_lon"
     names (graph) [gr_cols$yto] <- "to_lat"
 
-    # need to remove the hash to avoid re-loading the hashed version:
-    attr (graph, "hashc") <- NULL
-    gc <- dodgr_contract_graph (graph)
+    gc <- dodgr_contract_graph (graph, nocache = TRUE)
     edge_map <- get_edge_map (gc)
     geometry <- rcpp_aggregate_to_sf (graph, gc, edge_map)
 
